#!/bin/bash

# This script will merge a number of individual video files into a single video
# file, with fade in/fade out transitions in between.

count_frames () {
	ffprobe -v error -count_frames -select_streams v:0 \
		-show_entries stream=nb_read_frames \
		-of default=nokey=1:noprint_wrappers=1 "$@"
}

workdir=$(mktemp -d fadeXXXXXX)

trap "rm -rf $workdir" EXIT

echo "processing $1"
frames=$(count_frames "$1")
ffmpeg -v error -i "$1" -vf fade=out:$((frames-40)):40,fps=30 \
	-c:v libx264 -qp 0 \
	-strict -2 -y \
	$workdir/first.mp4

echo "file '$PWD/$workdir/first.mp4'" >> $workdir/concat

echo "processing $2"
vidtmp=$(mktemp $workdir/vidXXXXXX.mp4)
frames=$(count_frames "$2")
ffmpeg -v error -i "$2" \
  -vf fps=60 \
  -c:v libx264 -qp 0 \
  -strict -2 -y \
  $vidtmp
echo "file '$PWD/$vidtmp'" >> $workdir/concat

echo "concatenating segments"
# ffmpeg -f concat -safe 0 -i "$workdir/concat" -c copy -y "$workdir/final.mp4"
ffmpeg -v error -f concat -safe 0 -i "$workdir/concat" -map 0 \
  -c:v libx265 -c:a libopus -qp 0 -strict -2 -y "$workdir/final.mp4"

mv $workdir/final.mp4 $3

